Template Tags
=============
.. automodule:: ls.joyous.templatetags.joyous_tags


Tags
----
.. autofunction:: events_this_week
.. autofunction:: minicalendar
.. autofunction:: all_upcoming_events
.. autofunction:: subsite_upcoming_events
.. autofunction:: group_upcoming_events
.. autofunction:: future_exceptions
.. autofunction:: next_on
.. autofunction:: location_gmap

Filters
-------

.. autofunction:: time_display
.. autofunction:: at_time_display
.. autofunction:: date_display
